import { world, system } from "@minecraft/server";
import { ActionFormData } from "@minecraft/server-ui";

const afterEvents = world.afterEvents;

afterEvents.itemStartUseOn.subscribe((data) => {
    const block = data.block;
    const player = data.source;

    if (block.typeId == "minecraft:bed") {
        showForm(player);
    }
});

function showForm(player) {
    const formData = new ActionFormData();
    const time = world.getTimeOfDay();

    let currentTime = "Morning";

    // Midday = 6000
    if (time >= 5000 && time < 9000) {
        currentTime = "Midday";
    }

    // Evening = 12000 (Sunset)
    if (time >= 9000 && time < 13000) {
        currentTime = "Evening";
    }

    // Midday = 18000
    if (time >= 13000 || time < 1000) {
        currentTime = "Night";
    }

    let formButtons = [];

    formData.title("Sleep").body(`Current Time ${currentTime}`);

    if (currentTime != "Morning") {
        formData.button("Rest till Morning", "textures/ui/icons/Morning");
        formButtons.push("morning");
    }
    if (currentTime != "Midday") {
        formData.button("Rest till Midday", "textures/ui/icons/Midday");
        formButtons.push("midday");
    }
    if (currentTime != "Evening") {
        formData.button("Rest till Evening", "textures/ui/icons/Evening");
        formButtons.push("evening");
    }
    if (currentTime != "Night") {
        formData.button("Rest till Midnight", "textures/ui/icons/Midnight");
        formButtons.push("midnight");
    }

    formData.show(player).then((response) => {
        if (response.canceled) {
            return;
        }
        player.runCommandAsync(`title @a actionbar ${player.name} is in bed!`);
        player.runCommandAsync(`camera @s fade time 1 1 1`);

        system.runTimeout(() => {
            switch (formButtons[response.selection]) {
                case "morning":
                    world.setTimeOfDay(1000);
                    greetPlayer(player, "Morning");
                    break;
                case "midday":
                    world.setTimeOfDay(6000);
                    greetPlayer(player, "Afternoon");
                    break;
                case "evening":
                    world.setTimeOfDay(12000);
                    greetPlayer(player, "Evening");
                    break;
                case "midnight":
                    world.setTimeOfDay(18000);
                    greetPlayer(player, "Night");
                    break;
            }
        }, 20);
    });
}

function greetPlayer(player, text) {
    player.runCommandAsync(`title @s actionbar Good ${text}`);
}
